@@ -6,21 +6,17 @@
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
-jQuery(function () {
-    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
-    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
-    jQuery("form").submit(function () {
-        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
-        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
-        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
-        jQuery("//input[@type='submit']").attr({ "disabled": true });
-        return true;
-    });
-});
+var app = Img0ch.App;
+app.setBBS("<?cs var:BBS ?>");
+app.setBBSURI("<?cs var:BBSURI ?>");
+app.setCGIURI("<?cs var:CGIURI ?>");
+app.setStaticURI("<?cs var:StaticURI ?>");
+app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
 //-->
 </script>
 <style type="text/css">
@@ -40,18 +36,13 @@ jQuery(function () {
 
 <!--߂̃No͕-->
 <a href="<?cs var:BBSURI ?>/">fɖ߂遡</a>
-<!--֘Ay[W̃No͕(trackbackW[L̏ꍇ:Rĝ)-->
-<?cs if:ModuleTRACKBACK ?>
-<a href="<?cs var:TrackBack ?>">֘Ay[W</a>
-<?cs /if ?>
-
 <a href="<?cs var:ReadCGIURI ?>/">S</a>
 <a href="<?cs var:ReadCGIURI ?>/1-100">1-</a>
 <!--XɉăNo͂-->
 <?cs each:item = LinkStack ?><a href="<?cs var:ReadCGIURI ?>/<?cs var:item.start ?>-<?cs var:item.end ?>"><?cs var:item.start ?>-</a>
 <?cs /each ?>
-
-<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a><br><br>
+<a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
+<?cs if:Uploadable ?><a href="<?cs var:CGIURI ?>/img0ch-ufm.cgi/<?cs var:BBS ?>/<?cs var:KEY ?>/">t@CǗ</a><?cs /if  ?><br><br>
 
 <!--Xɂď݂oȂȂ邱Ƃ\o͂-->
 <?cs if:r100 ?>
@@ -73,7 +64,7 @@ X900𒴂Ă܂B1000𒴂ƕ\łȂȂB
 <font color="<?cs var:BBS_SUBJECT_COLOR ?>" size="+1"> <?cs var:Subject ?></font><br><br>
 
 <!--Xo͕-->
-<?cs each:item = Thread><dt><?cs var:item.resno ?>OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:item.mail ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?></dt><dd><?cs var:item.text ?><br><br></dd>
+<?cs each:item = Thread ?><dt><?cs var:item.resno ?>OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:item.mail ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:BBS_NAME_COLOR ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?></dt><dd><?cs var:item.text ?><br><br></dd>
 <?cs /each ?>
 </dl>
 
@@ -87,12 +78,13 @@ X900𒴂Ă܂B1000𒴂ƕ\łȂȂB
 <a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
 <a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
 <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
+<?cs if:Uploadable ?><a href="<?cs var:CGIURI ?>/img0ch-ufm.cgi/<?cs var:BBS ?>/<?cs var:KEY ?>/">t@CǗ</a><?cs /if  ?>
 <br>
 
 <!--tH[\(Xwȓłꍇ\)-->
 <?cs if:!r100 ?>
 
-<form method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
+<form class="comment" method="POST" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
 <input type="hidden" name="bbs" value="<?cs var:BBS ?>">
 <input type="hidden" name="key" value="<?cs var:KEY ?>">
 <input type="hidden" name="time" value="<?cs var:TimeStamp ?>">
@@ -101,6 +93,7 @@ OF<input type=text id="FROM" name="FROM" value="" size="19">
 E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
 <?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
 <textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
+<?cs if:Uploadable ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
 <small><?cs var:html_escape(VERSION) ?></small>
 </form>
 <?cs else ?>
