@@ -8,7 +8,7 @@
 <meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
 <meta http-equiv="Content-Script-Type" content="text/javascript" />
 <meta http-equiv="Content-Style-Type" content="text/css" />
-<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
+<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
@@ -17,12 +17,14 @@
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
+app.setBBS("<?cs var:BBS ?>");
 app.setBBSURI("<?cs var:BBSURI ?>");
 app.setCGIURI("<?cs var:CGIURI ?>");
+app.setStaticURI("<?cs var:StaticURI ?>");
 app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
 function redir(element) {
     app.redirectRenderer( element,
-        { "theme": "<?cs var:BBS_TYPE_THEME>" } );
+        { "theme": "<?cs var:BBS_TYPE_THEME ?>" } );
     return true;
 }
 //]]>
@@ -166,7 +168,7 @@ img { border: 0px; }
    <div class="field name">
     <br />摜F<input type="file" name="file" />
    </div>
-   <?cs if:BBS_IMG_REQUIRE_REMOVE_KEY ?>
+   <?cs if:Uploadable ?>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
@@ -184,6 +186,7 @@ img { border: 0px; }
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/" onclick="redir(this)">Sǂ</a>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/l50" onclick="redir(this)">ŐV50</a>
   <a href="<?cs var:CGIURI ?>/<?cs var:Renderer ?><?cs var:RendererSeparator ?><?cs var:BBS ?>/<?cs var:t.key ?>/1-100" onclick="redir(this)">1-100</a>
+  <?cs if:Uploadable ?><a href="<?cs var:CGIURI ?>/img0ch-ufm.cgi/<?cs var:BBS ?>/<?cs var:t.key ?>/">t@CǗ</a><?cs /if  ?>
   <a href="#top">̃gbv</a>
   <a href="./index.html">[h</a>
   <a href="#menu"></a>
