@@ -8,7 +8,7 @@
 <meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
 <meta http-equiv="Content-Script-Type" content="text/javascript" />
 <meta http-equiv="Content-Style-Type" content="text/css" />
-<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
+<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
@@ -17,8 +17,10 @@
 <script type="text/javascript">
 //<![CDATA[
 var app = Img0ch.App;
+app.setBBS("<?cs var:BBS ?>");
 app.setBBSURI("<?cs var:BBSURI ?>");
 app.setCGIURI("<?cs var:CGIURI ?>");
+app.setStaticURI("<?cs var:StaticURI ?>");
 app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
 //]]>
 </script>
@@ -82,6 +84,7 @@ img { border: 0px; }
     </a>
    <?cs /each ?>
    <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
+   <?cs if:Uploadable ?><a href="<?cs var:CGIURI ?>/img0ch-ufm.cgi/<?cs var:BBS ?>/<?cs var:KEY ?>/">t@CǗ</a><?cs /if  ?>
   </div>
   <div class="section">
    <p>
@@ -133,7 +136,7 @@ img { border: 0px; }
    <div class="field name">
     <br />摜F<input type="file" name="file" />
    </div>
-   <?cs if:BBS_IMG_REQUIRE_REMOVE_KEY ?>
+   <?cs if:Uploadable ?>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
@@ -155,11 +158,12 @@ img { border: 0px; }
   <a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
   <a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
   <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
+  <?cs if:Uploadable ?><a href="<?cs var:CGIURI ?>/img0ch-ufm.cgi/<?cs var:BBS ?>/<?cs var:key ?>/">t@CǗ</a><?cs /if  ?>
  </div>
 </div>
 
 <div class="footer">
- <?cs var:html_escape(VERSION ESCAPE) ?>
+ <?cs var:html_escape(VERSION) ?>
 </div>
 
 </body>
