@@ -11,26 +11,17 @@
 <meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
 <link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript">
 //<![CDATA[
-jQuery(function () {
-    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
-    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
-    jQuery("form.comment").submit(function () {
-        if ( !jQuery("input[@name='subject']", this).val() ) {
-            alert("TuWFNg܂");
-            return false;
-        }
-        if ( !jQuery("textarea[@name='MESSAGE']", this).val() ) {
-            alert("{܂");
-            return false;
-        }
-        jQuery("//input[@type='submit']").attr({ "disabled": true });
-        return true;
-    });
-});
+var app = Img0ch.App;
+app.setBBS("<?cs var:BBS ?>");
+app.setBBSURI("<?cs var:BBSURI ?>");
+app.setCGIURI("<?cs var:CGIURI ?>");
+app.setStaticURI("<?cs var:StaticURI ?>");
+app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
 //]]>
 </script>
 <style type="text/css">
