@@ -12,11 +12,10 @@
 <link rel="stylesheet" type="text/css" href="<?cs var:StaticURI ?>/css/domTT.css?v=<?cs var:html_escape(SecuredVersion) ?>" />
 
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/ajaxupload.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/fastserialize.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/pager.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/tablesorter.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/yahoo.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
-<script type="text/javascript" src="<?cs var:StaticURI ?>/js/yahoo/connection.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/domTT/domLib.js" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/domTT/domTT.js" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
@@ -26,6 +25,7 @@
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/cgroup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/cap.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/category.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/host.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/ip.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/filter/ngword.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
 <script type="text/javascript" src="<?cs var:StaticURI ?>/js/zeromin/log/action.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
@@ -139,8 +139,9 @@
 <a href="javascript:void(0)" onclick="(new Zeromin.Banner(2)).load()">副告知欄編集</a><br />
 <a href="javascript:void(0)" onclick="(new Zeromin.Banner(3)).load()">携帯用告知欄編集</a><br />
 <span><hr /></span>
-<a href="javascript:void(0)" onclick="Zeromin.getFilterIP().setBBS(0, '').load()">書き込み規制</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getFilterIP().setBBS(0, '').load()">書き込み規制(IP)</a><br />
 <a href="javascript:void(0)" onclick="$('div#filterIPAdd').toggle()">規制IP追加</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getFilterHost().setBBS(0, '').load()">書き込み規制(ホスト)</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getFilterNGWord().setBBS(0, '').load()">NGワード規制</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getFilterNGWord().render('create')">NGワード追加</a><br />
 <span><hr /></span>
@@ -148,6 +149,7 @@
 </div>
 <div class="hide" id="leftSystemMenu">
 <a href="javascript:void(0)" onclick="Zeromin.getSystem().loadEnvironmentInfo()">システム環境</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getSystem().loadMigrationInfo()">データ移行</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getSystem().loadRepositoryInfo()">レポジトリ</a><br />
 <span><hr /></span>
 <a href="javascript:void(0)" onclick="Zeromin.getLogAction().load()">ユーザー行動履歴</a><br />
@@ -158,9 +160,11 @@
 <a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 1)">ローカルルール編集</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 2)">メタデータ編集</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 3)">フッター編集</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getBBS().getMetadata(null, null, 4)">1000.txt編集</a><br />
 <span><hr /></span>
-<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterIP().load()">書き込み規制</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterIP().load()">書き込み規制(IP)</a><br />
 <a href="javascript:void(0)" onclick="$('div#filterIPAdd').toggle()">規制IP追加</a><br />
+<a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterHost().load()">書き込み規制(ホスト)</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterNGWord().load()">NGワード規制</a><br />
 <a href="javascript:void(0)" onclick="Zeromin.getBBS().getFilterNGWord().render('create')">NGワード追加</a><br />
 <span><hr /></span>
@@ -412,7 +416,7 @@
 <tr><td colspan="2"><hr /></td></tr>
 <tr>
 <td colspan="2" align="right">
-<button onclick="ZeroCH.getBanner().save()">
+<button onclick="Zeromin.getBanner().save()">
 &nbsp;&nbsp;設定&nbsp;&nbsp;
 </button>
 </td>
@@ -884,6 +888,36 @@ Tip.<br />
 </div><!-- div#capGroupForm -->
 
 
+<!-- 規制ホストの一覧を表示するコンテナ -->
+<div class="hide Container" id="filterHostRoot">
+
+<div class="hide State"></div>
+<div class="Bread"></div>
+
+<div>
+書き込みを禁止しているホストを表示しています。<br />
+<ul>
+<li>正規表現を使って規制を行うことが出来ます。</li>
+<li>規制情報は掲示板ごとと掲示板全体に分かれ、別々に保存されます。</li>
+</ul>
+</div>
+<div>
+<table border="0" cellspacing="2" width="100%">
+<td class="DetailTitle">規制ホスト</td>
+<td><textarea name="regexp" cols="70" rows="10"></textarea></td>
+<tr><td colspan="2"><hr /></td></tr>
+<tr><td colspan="2" align="right">
+<button onclick="Zeromin.getFilterHost().save()">
+&nbsp;&nbsp;保存&nbsp;&nbsp;
+</button>
+<input id="bbsOnFilterHost" type="hidden" name="bbs" value="" />
+</td></tr>
+</table>
+</div>
+
+</div><!-- div#filterIPRoot -->
+
+
 <div class="hide Container" id="logActionRoot">
 
 <div class="hide State"></div>
@@ -1219,6 +1253,51 @@ Zerominに登録されているユーザーを表示しています。
 </div><!-- div#bannerRoot -->
 
 
+<!-- スレッド終了を告知するレスを管理するコンテナ -->
+<div class="hide Container" id="threadEndRoot">
+
+<div class="State"></div>
+<div class="Bread"></div>
+
+<div>
+ここではスレッド終了時のレスを編集することが出来ます。<br />
+名前欄、メール欄、日付、本文が変更可能です。タグは利用出来ません。<br />
+日付の書式は「Over (数字) Thread」とする必要があります。<br />
+これ以外の書式で保存することは出来ません。<br />
+</div>
+
+<table border="0" cellspacing="2" width="100%">
+<tr><td colspan="2"><hr /></td></tr>
+<tr>
+<td class="DetailTitle">名前</td>
+<td><input type="text" size="50" value="" name="FROM" /></td>
+</tr>
+<tr>
+<td class="DetailTitle">メール</td>
+<td><input type="text" size="50" value="" name="mail" /></td>
+</tr>
+<tr>
+<td class="DetailTitle">日付・ID</td>
+<td><input type="text" size="50" value="" name="date" /></td>
+</tr>
+<tr>
+<td class="DetailTitle">本文</td>
+<td><textarea name="MESSAGE" cols="70" rows="10"></textarea></td>
+</tr>
+<tr>
+<td colspan="2" align="right">
+<button onclick="Zeromin.getMetadata().save('threadEndRoot')">
+&nbsp;&nbsp;保存&nbsp;&nbsp;
+</button>
+</td>
+</tr>
+</table>
+
+<input id="metadataId" type="hidden" name="id" value="" />
+
+</div><!-- div#threadEndRoot -->
+
+
 <div class="hide Container" id="pluginRoot">
 
 <div class="hide State"></div>
@@ -1383,6 +1462,8 @@ Zerominに登録されているユーザーを表示しています。
 </td></tr>
 <tr><td class="DetailTitle">使用するテンプレート名</td>
 <td><input type="text" size="80" name="BBS_TEMPLATE" value=""></td></tr>
+<tr><td class="DetailTitle">最大レス数</td>
+<td><input type="text" size="80" name="BBS_RES_MAX" value=""></td></tr>
 <tr><td colspan="2"><hr></td></tr>
 <tr><td colspan="2" align="right">
 <button onclick="Zeromin.getSetting().save('div#settingMain')">
@@ -1715,10 +1796,16 @@ SETTING.TXTから値を見ることが出来ます。
 <td><input type="checkbox" name="BBS_IMG_DECODE_FILENAME" value="checked" />表示する</td>
 <td class="DetailTitle">携帯からのメール投稿を許可する</td>
 <td><input type="checkbox" name="BBS_ACCEPT_MAILPOST" value="checked" />許可する</td></tr>
+<tr><td class="DetailTitle">アップロード時に削除キーを必須にする</td>
+<td><input type="checkbox" name="BBS_IMG_REQUIRE_REMOVE_KEY" value="checked" />必須にする</td>
+<td class="DetailTitle">アップロード時にダウンロードキーを必須にする</td>
+<td><input type="checkbox" name="BBS_IMG_REQUIRE_DOWNLOAD_KEY" value="checked" />必須にする</td></tr>
 <tr><td class="DetailTitle">アップロードを許可する拡張子</td>
-<td colspan="3">
+<td>
 <textarea name="BBS_IMG_ALLOWED_EXT" cols="10" rows="5"></textarea>
-</td></tr>
+</td>
+<td class="DetailTitle">ファイルの有効期限(秒単位：0で無限)</td>
+<td><input type="text" size="8" name="BBS_IMG_EXPIRES" value="" /></td></tr>
 <tr><td colspan="4"><hr></td></tr>
 <tr><td colspan="4" align="right">
 <button onclick="Zeromin.getSetting().save('div#settingUpload')">
@@ -1999,6 +2086,7 @@ subject.txtに存在するスレッドを表示しています。<br /><br />
 <input type="hidden" name="P" value="" />
 <input type="hidden" name="C" value="thread" />
 <input type="hidden" name="M" value="doImport" />
+<input type="hidden" name="js" value="" />
 <input type="submit" value="インポート">
 </form>
 <hr>
@@ -2360,6 +2448,43 @@ Zerominに登録されているユーザーを表示しています。
 </div><!-- div#systemEnvironmentRoot -->
 
 
+<div class="hide Container" id="systemMigrateRoot">
+
+<div class="hide State"></div>
+<div class="Bread"></div>
+
+<div>
+過去のデータ(2005/12/30以前)を現行版のデータに移行します。<br />
+管理権限を持つグループに所属するユーザーのみ実行可能です。
+
+<div id="migrateSelect">
+<p>
+移行するデータ<br />
+<input type="checkbox" name="archive" value="1" id="migrateArchive" />
+<label for="migrateArchive">過去ログ</label><br />
+<input type="checkbox" name="pool" value="1" id="migratePool" />
+<label for="migratePool">プールスレッド</label><br />
+<input type="checkbox" name="banner" value="1" id="migrateBanner" />
+<label for="migrateBanner">バナー</label><br />
+<input type="checkbox" name="category" value="1" id="migrateCategory" />
+<label for="migrateCategory">カテゴリ</label><br />
+<input type="checkbox" name="user" value="1" id="migrateUser" />
+<label for="migrateUser">ユーザー</label><br />
+<input type="checkbox" name="cap" value="1" id="migrateCap" />
+<label for="migrateCap">キャップ</label><br />
+<input type="checkbox" name="hostlog" value="1" id="migrateHostlog" />
+<label for="migrateHostlog">ホストログ</label><br />
+<input type="checkbox" name="threadlog" value="1" id="migrateThreadlog" />
+<label for="migrateThreadlog">スレッドログ</label><br />
+</p>
+<button onclick="Zeromin.getSystem().startMigration()">データ移行を開始する</button>
+</div>
+
+</div>
+
+</div><!-- div#systemMigrateRoot -->
+
+
 <div class="hide Container" id="systemRepositoryRoot">
 
 <div class="hide State"></div>
@@ -2386,7 +2511,7 @@ ZIP形式で作成した場合<br />
 
 </div>
 
-</div><!-- div#systemEnvironmentRoot -->
+</div><!-- div#systemRepositoryRoot -->
 
 
 </td>
