@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  * Zeromin
- * $Id: zeromin.js 139 2007-01-28 11:54:38Z hikarin $
+ * $Id: zeromin.js 227 2007-02-13 13:24:00Z hikarin $
  */
 
 function login() {
@@ -38,9 +38,8 @@ function login() {
         var io = new Zeromin.IO(ZEROMIN_CGI_URI, user, pass);
         io.load(
             [ { "name": "uv", "value": 1 } ],
-            function (responseText) {
+            function (rs) {
                 try {
-                    var rs = eval('(' + responseText + ')');
                     if ( rs["ok"] && rs["loginOK"] ) {
                         $(document.getElementById("loggedUser")).html(user);
                         process.html("カテゴリ一覧を取得中です...");
@@ -71,7 +70,8 @@ function login() {
                     }
                 } catch(e) {
                     process.hide();
-                    var str = "例外が発行されました<br />" + e;
+                    var str = "例外が発行されました<br />["
+                        + e.name + "] " + ( e.description || e.message );
                     loginError.html(str).show();
                 }
             },
@@ -478,7 +478,7 @@ Zeromin.IO = function(url, user, pass, timeout) {
 
 Zeromin.IO.prototype = {
     "load": function(param, callback, self, noEval) {
-        var cb;
+        var success;
         if ( self != null ) {
             var cache = self.getCache();
             if ( cache != null) {
@@ -498,50 +498,65 @@ Zeromin.IO.prototype = {
             "color":        "blue"
         }).html("読み込み中...").show();
         if (noEval) {
-            cb = function(responseText) { callback(responseText) };
+            success = function(responseText) { callback(responseText) };
         }
         else {
-            cb = function(responseText) {
+            success = function(rs) {
                 try {
-                    var res = eval('(' + responseText + ')');
-                    callback(new Zeromin.IO.Storage(res, self, false));
+                    callback(new Zeromin.IO.Storage( rs, self, false ));
                 } catch(e) {
-                    //console.log(e);
                     Zeromin.DOM.statusNG(
-                          "[" + e.name + "] " + ( e.description || e.message )
-                        + "<p>" + responseText + "</p>"
+                        "[" + e.name + "] "
+                        + ( e.description || e.message )
+                        + "<p>" + rs + "</p>"
                     );
                     Zeromin.DOM.enableMethodSelector();
                 }
             }
         }
-        param.push({ "name": "I", "value": this.user });
-        param.push({ "name": "P", "value": this.pass });
-        $.post(this.url, param, cb);
+        var failure = function( xml, status, e ) {
+            Zeromin.DOM.statusNG(
+                "[" + e.name + "] "
+                + ( e.description || e.message )
+                + "<p>" + xml.responseText + "</p>"
+            );
+            Zeromin.DOM.enableMethodSelector();
+        };
+        param.push({ "name": "I",  "value": this.user });
+        param.push({ "name": "P",  "value": this.pass });
+        param.push({ "name": "js", "value": 1 });
+        $.ajax({
+            "data": param,
+            "dataType": "json",
+            "error": failure,
+            "global": false,
+            "success": success,
+            "type": "POST",
+            "url": this.url
+            });
     },
     "upload": function(formId, callback) {
-        var cb = {
-            "upload": function(o) {
-                //console.log( o.responseText );
-                o.responseText.match(/<[pP][rR][eE]>([^<]+)(<\/pre>)?/);
-                var rs = RegExp.$1;
-                try {
-                    var res = eval('(' + rs + ')');
-                    callback(new Zeromin.IO.Storage(res, self, false));
-                } catch(e) {
-                    //console.log(e);
-                    Zeromin.DOM.statusNG(
-                          "[" + e.name + "] " + ( e.description || e.message )
-                        + "<p>" + responseText + "</p>"
-                    );
-                    Zeromin.DOM.enableMethodSelector();
-                }
-            },
-            "failure": function(o) {
-                Zeromin.DOM.statusNG(o.responseText);
+        var success = function(rs) {
+            try {
+                eval("rs = " + jQuery(rs).text());
+                callback(new Zeromin.IO.Storage( rs, self, false ));
+            } catch(e) {
+                console.log(e);
+                Zeromin.DOM.statusNG(
+                    "[" + e.name + "] "
+                    + ( e.description || e.message )
+                    + "<p>" + rs + "</p>"
+                );
                 Zeromin.DOM.enableMethodSelector();
-            },
-            "timeout": 5000
+            }
+        }
+        var failure = function( xml, status, e ) {
+            Zeromin.DOM.statusNG(
+                "[" + e.name + "] "
+                + ( e.description || e.message )
+                + "<p>" + xml.responseText + "</p>"
+            );
+            Zeromin.DOM.enableMethodSelector();
         };
         $("div.State").css({
             "background":   "#eeeeff",
@@ -549,10 +564,36 @@ Zeromin.IO.prototype = {
             "color":        "blue"
         }).html("読み込み中...").show();
         var formDOM = document.getElementById(formId);
-        $( "input[@name='I']", formDOM ).val(this.user);
-        $( "input[@name='P']", formDOM ).val(this.pass);
-        YAHOO.util.Connect.setForm( formDOM, true );
-        YAHOO.util.Connect.asyncRequest( "POST", this.url, cb );
+        $( "input[@name='I']",  formDOM ).val(this.user);
+        $( "input[@name='P']",  formDOM ).val(this.pass);
+        $( "input[@name='js']", formDOM ).val('1');
+        /* for jQuery 1.1 compatiblity */
+        jQuery.ajaxSettings = {
+            "global": true,
+            "type": "GET",
+            "timeout": 0,
+            "contentType": "application/x-www-form-urlencoded",
+            "processData": true,
+            "async": true,
+            "data": null
+        };
+        jQuery.handleError = function(s, xml, status, e ) {
+            // If a local callback was specified, fire it
+            if ( s.error ) s.error( xml, status, e );
+            // Fire the global callback
+            if ( s.global )
+                jQuery.event.trigger( "ajaxError", [xml, s, e] );
+        };
+        $.ajaxUpload({
+            "dataType": "text",
+            "error": failure,
+            "global": false,
+            "secureuri": false,
+            "success": success,
+            "type": "POST",
+            "uploadform": formDOM,
+            "url": this.url
+            });
     }
 };
 
