@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: BBS.pm 230 2007-02-13 14:30:18Z hikarin $
 #
 
 package Img0ch::App::BBS;
@@ -38,15 +38,17 @@ BEGIN {
 sub new {
     my ( $iClass, $iKernel, @args ) = @_;
     bless {
+        _config                     => $iKernel->get_config(),
+        _host                       => '',
+        _ip                         => '',
+        _ip_int                     => 0,
+        _request                    => Img0ch::Request->new(@args),
+        _serial                     => '',
         __agent                     => 0,
         __bbs                       => undef,
         __cap                       => undef,
-        __config                    => $iKernel->get_config(),
         __error                     => '',
         __error_args                => {},
-        __host                      => '',
-        __ip                        => '',
-        __ip_int                    => 0,
         __kernel                    => $iKernel,
         __key                       => 0,
         __mkthread                  => 0,
@@ -57,10 +59,8 @@ sub new {
         __param_mail                => '',
         __param_id                  => '',
         __param_subject             => '',
-        __request                   => Img0ch::Request->new(@args),
         __resmax                    => 0,
         __setting                   => undef,
-        __serial                    => '',
         __sage                      => 0,
         __subject                   => undef,
         __template_tag_confirm      => [],
@@ -77,29 +77,32 @@ sub new {
 sub run {
     my ($iApp) = @_;
 
-    $iApp->init()    or return $iApp->_redirect_error();
+    $iApp->init()    or return $iApp->redirect_error('error');
     $iApp->_switch() or return 0;
     $iApp->get_host();
-    $iApp->validate()     or return $iApp->_redirect_error();
-    $iApp->is_writeable() or return $iApp->_redirect_error();
+    $iApp->validate()     or return $iApp->redirect_error('error');
+    $iApp->is_writeable() or return $iApp->redirect_error('error');
     $iApp->get_date();
-    $iApp->post() or return $iApp->_redirect_error();
-    $iApp->update_subback( undef, 1 );
-    $iApp->update_index();
-    $iApp->_redirect_success();
+    $iApp->post() or return $iApp->redirect_error('error');
+    $iApp->update_subback( undef, 1, 0 );
+    $iApp->update_index( undef, 1, 0 );
+    $iApp->redirect_success();
     return 1;
 }
 
 sub init {
     my ($iApp)   = @_;
-    my $iConfig  = $iApp->{__config};
-    my $iRequest = $iApp->{__request};
+    my $iConfig  = $iApp->{_config};
+    my $iRequest = $iApp->{_request};
+
+    $iConfig->get('Maintenance')
+        and die 'img0ch MAINTENANCE: Please try again later.', "\n";
     $iRequest->init($iConfig);
 
     require Img0ch::BBS;
     my $iBBS
         = Img0ch::BBS->new( $iApp->{__kernel}, { bbs => $iRequest->bbs(), } );
-    if ( !$iBBS->id() ) {
+    if ( !$iBBS->get_id() ) {
         $iApp->{__error} = 'INVALID_POST';
         return 0;
     }
@@ -110,8 +113,6 @@ sub init {
     require Img0ch::Setting;
     my $iSetting = Img0ch::Setting->new($iBBS);
     $iSetting->load();
-    my $path = $iSetting->get('BBS_COOKIE_PATH') || '/';
-    my $expires = 2592000;
     $iApp->{__setting} = $iSetting;
     $iApp->{__now}     = $iRequest->now();
 
@@ -121,18 +122,17 @@ sub init {
     $iApp->{__agent}    = $iRequest->agent();
     $iApp->{__key}      = $key;
     $iApp->{__mkthread} = $iThread->load() ? 0 : 1;
-    $iApp->{__resmax}   = $iConfig->get_int('ResMAX') || 1000;
     $iApp->{__thread}   = $iThread;
     1;
 }
 
 sub get_host {
     my ($iApp)   = @_;
-    my $iRequest = $iApp->{__request};
+    my $iRequest = $iApp->{_request};
     my $ip       = $iRequest->ip();
     my $ip_int   = $iRequest->ip_int();
     my $host = gethostbyaddr( $ip_int, 2 ) || $ip;
-    my $re = qr/(\d+)\.(\d+)\.(\d+)\.(\d+)/;
+    my $re = qr/(\d+)\.(\d+)\.(\d+)\.(\d+)/xms;
 
     if (   $iRequest->get_header('via') =~ /$re/xms
         || $iRequest->get_header('x-forwarded-for') =~ /$re/xms
@@ -142,17 +142,17 @@ sub get_host {
             || join( '.', $1, $2, $3, $4 );
         $host .= '&lt;' . $proxy . '&gt;';
     }
-    $iApp->{__host}   = $host;
-    $iApp->{__ip}     = $ip;
-    $iApp->{__ip_int} = $ip_int;
+    $iApp->{_host}   = $host;
+    $iApp->{_ip}     = $ip;
+    $iApp->{_ip_int} = $ip_int;
 
     my $mode = $iApp->{__agent};
     if ( $mode > 0 ) {
-        my $serial = $iApp->{__serial} = [
+        my $serial = $iApp->{_serial} = [
             sub {''},
             sub {
                 my $agent = $_[0]->get_header('user-agent');
-                return $1 if $agent =~ m{/ser(\w{11})$}xms;
+                return $1 if $agent =~ m{/ser(\w{11})\z}xms;
                 return $1 if $agent =~ /;ser(\w{15});/xms;
                 '';
             },
@@ -199,18 +199,22 @@ sub get_host {
 sub validate {
     my ($iApp)   = @_;
     my $iBBS     = $iApp->{__bbs};
-    my $iConfig  = $iApp->{__config};
+    my $iConfig  = $iApp->{_config};
     my $iSetting = $iApp->{__setting};
-    my $iRequest = $iApp->{__request};
+    my $iRequest = $iApp->{_request};
     my $charset  = $iApp->{__kernel}->get_encoding(1);
     my $name = $iRequest->param_multibyte( 'FROM', $charset );
     my $mail = $iRequest->param_multibyte( 'mail', $charset );
 
     require Img0ch::Cap;
+    $mail =~ s/&(?:amp;)?\#(\d+;)/&&$1/gxms;
     $mail =~ s/\#(.+)\z//xms;
-    my $iCap = Img0ch::Cap->new( $iBBS, ( $1 || '' ) );
+    my $pass = $1 || '';
+    my $iCap = Img0ch::Cap->new( $iBBS, $pass );
     $iCap->load();
     $iCap->is_valid();
+    $mail =~ s/&&(\d+;)/&#$1/gxms;
+
     my $limitless = $iCap->can_post_without_limit();
     if ( !$limitless ) {
         if ( $iSetting->get_int('BBS_MAIL_COUNT') < length $mail ) {
@@ -250,7 +254,7 @@ sub validate {
         $iConfig->get('multibyte.TRUE_TRIP')
     );
 
-    my $host = $iApp->{__host};
+    my $host = $iApp->{_host};
     $name =~ s|\Afusianasan|</b>$host<b>|xms;
     $name =~ s|fusianasan| </b>$host<b>|gxms;
     if ($capn) {
@@ -328,7 +332,7 @@ sub is_writeable {
     my ($iApp) = @_;
 
     my $iBBS    = $iApp->{__bbs};
-    my $iConfig = $iApp->{__config};
+    my $iConfig = $iApp->{_config};
     $iApp->_plugin( $iBBS, $iConfig, 'bbs.filter', 'DisableBBSFilterPlugin' )
         or return 0;
 
@@ -346,6 +350,8 @@ sub is_writeable {
         }
     }
 
+    my $resmax = $iApp->{__resmax} = $iConfig->get_int('ResMAX')
+        || $iSetting->get_int('BBS_RES_MAX') || 1000;
     if ( $iApp->{__mkthread} ) {
         if ( $iSetting->is_checked('BBS_THREADCAPONLY')
             and !$iCap->can_create_thread_to_readonly() )
@@ -356,7 +362,7 @@ sub is_writeable {
         require Img0ch::Filter::Thread;
         if ( !$iCap->can_create_thread_limitless() ) {
             my $args = {
-                ip    => $iApp->{__ip_int},
+                ip    => $iApp->{_ip_int},
                 max   => $iSetting->get_int('BBS_THREAD_TATESUGI'),
                 pass  => $iCap->can_create_thread_limitless(),
                 stamp => $iApp->{__now},
@@ -369,59 +375,30 @@ sub is_writeable {
     }
     else {
         require Img0ch::Filter::Res;
-        my $host = $iApp->{__host};
-        if ( $iSetting->is_checked('BBS_JP_CHECK') ) {
-            if ( !$iCap->can_pass_proxy_access() and $host !~ /\.jp$/ ) {
-                my $ret = 0;
-                $ret = eval {
-                    require IP::Country;
-                    my $ic = IP::Country::Fast->new();
-                    ( $ic->inet_atocc( $iApp->{__ip} ) || '' ) eq 'JP'
-                        and return 1;
-                };
-                if ( !$ret ) {
-                    my $ok   = 0;
-                    my $path = $iConfig->get('SystemPath') . '/HOST-jp.ini';
-                    my $jp   = Img0ch::Config->new();
-                    $jp->load($path);
-                    for my $regex ( keys %{ $jp->get('regex.*') } ) {
-                        my $re = qr/$regex/;
-                        if ( $host =~ /$re/xms ) {
-                            $ok = 1;
-                            last;
-                        }
-                    }
-                    if ( !$ok ) {
-                        $iApp->{__error} = 'POST_FROM_NOT_JP_HOST';
-                        return 0;
-                    }
-                }
-            }
-        }
         my $iThread  = $iApp->{__thread};
         my $mkthread = $iApp->{__mkthread};
         my $error    = 0;
         my $max_size = $iSetting->get_int('BBS_DATMAX') * 1024;
-        if ( !$mkthread and !$iThread->can_write( \$error, $max_size ) ) {
-            require Img0ch::Error;
+        if ( !$mkthread and !$iThread->can_write(
+            \$error, $max_size, $resmax ) ) {
             $iApp->{__error} = [
-                'INVALID_POST',      'POST_STOPPED_THREAD',
+                'UNKNOWN_ERROR',     'POST_STOPPED_THREAD',
                 'POST_MOVED_THREAD', 'POST_OVER_THREAD',
                 'LIMIT_THREAD_SIZE',
             ]->[$error];
-            %{ $iApp->{__error_args} } = ( RESMAX => $iApp->{__resmax} );
+            %{ $iApp->{__error_args} } = ( RESMAX => $resmax );
             return 0;
         }
         my $samba = $iConfig->get_int('SambaCount') || 30;
         my $args = {
             duplicate_ok => $iCap->can_double_post(),
-            ip           => $iApp->{__ip_int},
+            ip           => $iApp->{_ip_int},
             len          => length $iApp->{__param_MESSAGE},
             samba_close  => $samba,
             samba_count  => ( $iConfig->get_int('SambaCount') || 30 ),
             samba_ok     => $iCap->can_post_sambaless(),
             samba_wait   => ( $iConfig->get_int('SambaWait') || 3600 ),
-            serial       => $iApp->{__serial},
+            serial       => $iApp->{_serial},
             stamp        => $iApp->{__now},
             store        => ( $iConfig->get_int('LogStackMAX') || 255 ),
             timeclose    => $iSetting->get_int('timeclose'),
@@ -443,12 +420,12 @@ sub is_writeable {
 
 sub get_date {
     my ($iApp) = @_;
-    my $iConfig  = $iApp->{__config};
+    my $iConfig  = $iApp->{_config};
     my $now      = $iApp->{__now};
-    my $host     = $iApp->{__host};
+    my $host     = $iApp->{_host};
     my $id       = $iApp->get_poster_id(
          $now, $host, $iConfig->get('Seed'),
-         $iApp->{__bbs}->bbs(), $iApp->{__serial} );
+         $iApp->{__bbs}->get_name(), $iApp->{_serial} );
     my $mode     = '';
     my $iCap     = $iApp->{__cap};
     my $iSetting = $iApp->{__setting};
@@ -458,7 +435,7 @@ sub get_date {
         $host =~ /p2\.2ch\.net/xms and $mode = 'P';
     }
     if ( $iSetting->is_checked('BBS_NO_ID') ) {
-        $id = ' ' . $mode;
+        $id = length $mode ? " ${mode}" : '';
     }
     elsif ( $iCap->can_id_to_unknown() ) {
         $id = ' ID:???' . $mode;
@@ -492,7 +469,7 @@ sub get_date {
 sub post {
     my ($iApp)  = @_;
     my $error   = 0;
-    my $iConfig = $iApp->{__config};
+    my $iConfig = $iApp->{_config};
     my $iThread = $iApp->{__thread};
 
     my $iBBS  = $iApp->{__bbs};
@@ -502,7 +479,7 @@ sub post {
         or return 0;
 
     my $key      = $iApp->{__key};
-    my $iRequest = $iApp->{__request};
+    my $iRequest = $iApp->{_request};
     my $iSetting = $iApp->{__setting};
     my $mkthread = $iApp->{__mkthread};
     my $mode     = $iSetting->get('BBS_MODE');
@@ -512,19 +489,48 @@ sub post {
         and $iRequest->is_uploadable('file')
         )
     {
-        $iApp->_upload( $count, $key, $iBBS, $iConfig, $iRequest, $iSetting );
+        $iApp->_upload( $count, $key, $iBBS, $iConfig, $iRequest, $iSetting )
+            or return 0;
     }
 
     require Img0ch::Log;
     my $iLog = Img0ch::Log->new( $iBBS, $key );
     $iLog->add(
         $count,
-        [   $iApp->{__now},    $iApp->{__ip_int},
-            $iApp->{__serial}, $iRequest->get_header('user-agent'),
+        [   $iApp->{__now},    $iApp->{_ip_int},
+            $iApp->{_serial}, $iRequest->get_header('user-agent'),
         ]
     );
     $iLog->save();
 
+    $iThread->set(
+        [   $iApp->{__param_FROM}, $iApp->{__param_mail},
+            $iApp->{__param_date}, $iApp->{__param_id},
+            $iApp->{__param_MESSAGE}, $iApp->{__param_subject},
+        ]
+    );
+    $iThread->save() or return 0;
+
+    if ( $iApp->{__resmax} <= $count ) {
+        require Img0ch::Metadata;
+        my $iMeta = Img0ch::Metadata->new($iBBS);
+        my $content = $iMeta->thread_end();
+        if (!$content) {
+            my $iKernel = $iApp->{__kernel};
+            my $path = join '/', $iConfig->get('SystemPath'), '1000.txt';
+            local ( *FH, $! );
+            open *FH, "<${path}" or $iKernel->throw_io_exception($path);
+            $content = do { local $/ = undef; <FH> };
+            close *FH or $iKernel->throw_io_exception($path);
+        }
+        my $end = [ split '<>', $content ];
+        $end->[4] = $end->[3];
+        $end->[3] = '';
+        $iThread->set($end);
+        $iThread->save() or return 0;
+        $count++;
+    }
+
     require Img0ch::Subject;
     my $iSubject = Img0ch::Subject->new($iBBS);
     $iSubject->load();
@@ -537,30 +543,13 @@ sub post {
     $iSubject->save() or return 0;
     $iApp->{__subject} = $iSubject;
 
-    $iThread->set(
-        [   $iApp->{__param_FROM}, $iApp->{__param_mail},
-            $iApp->{__param_date}, $iApp->{__param_id},
-            $iApp->{__param_MESSAGE}, $iApp->{__param_subject},
-        ]
-    );
-    $iThread->save() or return 0;
-
-    if ( $iApp->{__resmax} <= $count ) {
-        require Img0ch::Metadata;
-        my $iMeta = Img0ch::Metadata->new($iBBS);
-        my $end = [ split '<>', $iMeta->thread_end() ];
-        $end->[4] = $end->[3];
-        $end->[3] = '';
-        $iThread->set($end);
-        $iThread->save();
-    }
     1;
 }
 
 sub update_subback {
-    my ( $iApp, $iBBS, $execute_plugins ) = @_;
+    my ( $iApp, $iBBS, $execute_plugins, $nodisk ) = @_;
     $iBBS ||= $iApp->{__bbs};
-    my $iConfig = $iApp->{__config};
+    my $iConfig = $iApp->{_config};
 
     if ($execute_plugins) {
         $iApp->_plugin( $iBBS, $iConfig, 'bbs.write.post',
@@ -599,23 +588,25 @@ sub update_subback {
 
     require Img0ch::Metadata;
     require Img0ch::Template;
-    my $iMeta     = Img0ch::Metadata->new($iBBS);
+    my $iMeta = Img0ch::Metadata->new($iBBS);
+    my $param = {
+        ( map { %{$_} } @{ $iApp->{__template_tag_subback} } ),
+        'Banner'   => $iMeta->main_banner(),
+        'Renderer' => ( $iConfig->get('Renderer') || 'read.cgi' ),
+        'RendererSeparator' =>
+            ( $iConfig->get('RendererSeparator') || '/' ),
+        'Threads' => $stack,
+    };
+    $nodisk and return $param;
+
     my $iTemplate = Img0ch::Template->new(
         $iBBS,
         {   file    => 'subback',
             setting => $iSetting,
-            version => $iApp->{__request}->credit(),
-        }
-    );
-    $iTemplate->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_subback} } ),
-            'Banner'   => $iMeta->main_banner(),
-            'Renderer' => ( $iConfig->get('Renderer') || 'read.cgi' ),
-            'RendererSeparator' =>
-                ( $iConfig->get('RendererSeparator') || '/' ),
-            'Threads' => $stack,
+            version => $iApp->{_request}->credit(),
         }
     );
+    $iTemplate->param($param);
     $iApp->{__meta} = $iMeta;
 
     $iTemplate->save( $iBBS->path('subback.html') );
@@ -623,9 +614,9 @@ sub update_subback {
 }
 
 sub update_index {
-    my ( $iApp, $iBBS ) = @_;
-    my $iConfig  = $iApp->{__config};
-    my $iRequest = $iApp->{__request};
+    my ( $iApp, $iBBS, $execute_plugins, $nodisk ) = @_;
+    my $iConfig  = $iApp->{_config};
+    my $iRequest = $iApp->{_request};
     $iConfig->get('FastWriteMode') and return 1;
     $iBBS ||= $iApp->{__bbs};
 
@@ -658,8 +649,8 @@ sub update_index {
     my $limit               = $iSetting->get_int('BBS_MAX_MENU_THREAD') + 1;
     my $cnum                = $iSetting->get_int('BBS_CONTENTS_NUMBER');
     my $first               = $num > 1 ? 2 : 1;
-    my $bbs                 = $iBBS->bbs();
-    my $id                  = $iBBS->id();
+    my $bbs                 = $iBBS->get_name();
+    my $id                  = $iBBS->get_id();
     my $float_thread_stack  = [];
     my $stored_thread_stack = [];
     my $i                   = 1;
@@ -701,10 +692,42 @@ sub update_index {
         $i++;
     }
 
-    my $iMeta          = $iApp->{__meta} || Img0ch::Metadata->new($iBBS);
-    my $head           = $iMeta->head();
-    my $meta           = $iMeta->meta();
-    my $foot           = $iMeta->foot();
+    my $iMeta       = $iApp->{__meta} || Img0ch::Metadata->new($iBBS);
+    my $head        = $iMeta->head();
+    my $meta        = $iMeta->meta();
+    my $foot        = $iMeta->foot();
+    my $index_param = {
+        ( map { %{$_} } @{ $iApp->{__template_tag_index} } ),
+        'Banner'   => $iMeta->main_banner(),
+        'FOOT'     => $foot,
+        'HEAD'     => $head,
+        'META'     => $meta,
+        'Renderer' => ( $iConfig->get('Renderer') || 'read.cgi' ),
+        'RendererSeparator' =>
+            ( $iConfig->get('RendererSeparator') || '/' ),
+        'Stored'    => $stored_thread_stack,
+        'SubBanner' => $iMeta->sub_banner(),
+        'Threads'   => $float_thread_stack,
+    };
+    my $mobile_float_thread_param
+        = [ @{$float_thread_stack}, @{$stored_thread_stack}, ];
+    @{$mobile_float_thread_param} = splice(
+        @{$mobile_float_thread_param},
+        0, $iSetting->get_int('BBS_MB_THREAD_NUMBER'),
+    );
+    my $mi_param    = {
+        ( map { %{$_} } @{ $iApp->{__template_tag_mobile_index} } ),
+        'Banner'  => $iMeta->mobile_banner(),
+        'Count'   => scalar @{$mobile_float_thread_param},
+        'CR'      => "\n",
+        'FOOT'    => $foot,
+        'HEAD'    => $head,
+        'META'    => $meta,
+        'Next'    => 1 + $iSetting->get_int('BBS_MB_THREAD_NUMBER'),
+        'Threads' => $mobile_float_thread_param,
+    };
+    $nodisk and return ( $index_param, $mi_param );
+
     my $iTemplateIndex = Img0ch::Template->new(
         $iBBS,
         {   file    => 'index',
@@ -712,28 +735,9 @@ sub update_index {
             version => $iRequest->credit(),
         }
     );
-    $iTemplateIndex->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_index} } ),
-            'Banner'   => $iMeta->main_banner(),
-            'FOOT'     => $foot,
-            'HEAD'     => $head,
-            'META'     => $meta,
-            'Renderer' => ( $iConfig->get('Renderer') || 'read.cgi' ),
-            'RendererSeparator' =>
-                ( $iConfig->get('RendererSeparator') || '/' ),
-            'Stored'    => $stored_thread_stack,
-            'SubBanner' => $iMeta->sub_banner(),
-            'Threads'   => $float_thread_stack,
-        }
-    );
+    $iTemplateIndex->param($index_param);
     $iTemplateIndex->save( $iBBS->path('index.html') );
 
-    my $mobile_float_thread_param
-        = [ @{$float_thread_stack}, @{$stored_thread_stack}, ];
-    @{$mobile_float_thread_param} = splice(
-        @{$mobile_float_thread_param},
-        0, $iSetting->get_int('BBS_MB_THREAD_NUMBER'),
-    );
     my $iTemplateMobile = Img0ch::Template->new(
         $iBBS,
         {   file    => 'i_index',
@@ -741,18 +745,7 @@ sub update_index {
             version => $iRequest->credit(),
         }
     );
-    $iTemplateMobile->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_mobile_index} } ),
-            'Banner'  => $iMeta->mobile_banner(),
-            'Count'   => scalar @{$mobile_float_thread_param},
-            'CR'      => "\n",
-            'FOOT'    => $foot,
-            'HEAD'    => $head,
-            'META'    => $meta,
-            'Next'    => 1 + $iSetting->get_int('BBS_MB_THREAD_NUMBER'),
-            'Threads' => $mobile_float_thread_param,
-        }
-    );
+    $iTemplateMobile->param($mi_param);
     $iTemplateMobile->save( $iBBS->path('i/index.html'),
         sub { ${ $_[0] } =~ s/\n//gxms; ${ $_[0] } } );
     1;
@@ -801,6 +794,7 @@ sub trip {
     my ( $iClass, $name, $column, $trip ) = @_;
     $trip ||= pack( 'C*', ( 0x81, 0x9f ) );
 
+    $$name =~ s/&(?:amp;)?\#(\d+;)/&&$1/gxms;
     if ( $$name =~ /\A(.*?)\#(.+)\z/xms ) {
         my ( $nm, $key ) = ( $1, $2 );
         my $salt = substr( substr( $key, 0, 8 ) . 'H.', 1, 2 );
@@ -808,17 +802,20 @@ sub trip {
         $salt =~ tr/\x3A-\x40\x5B-\x60\x00-\x2D\x7B-\xFF/A-Ga-f./;
         $column = -1 * $column;
         my $t = substr crypt( $key, $salt ), $column;
+        $$name =~ s/&&(\d+;)/&#$1/gxms;
         $$name = $nm ? "${nm} </b>${trip}${t} <b>" : "</b>${trip}${t} <b>";
         return 1;
     }
-    0;
+
+    $$name =~ s/&&(\d+;)/&#$1/gxms;
+    return 0;
 }
 
 sub escape_chars {
     my ( $iApp, $data, $f, $iConfig ) = @_;
     my @q = ( 0x81, 0x68 );
 
-    $iConfig ||= $iApp->{__config};
+    $iConfig ||= $iApp->{_config};
     my $cap1 = $iConfig->get('multibyte.TRUE_CAP')
         || pack( 'C*', ( 0x81, 0x9a ) );
     my $cap0 = $iConfig->get('multibyte.FALSE_CAP')
@@ -862,8 +859,8 @@ sub escape_chars {
 
 sub is_referer {
     my ($iApp)   = @_;
-    my $iRequest = $iApp->{__request};
-    my $svr      = $iApp->{__config}->get('Server');
+    my $iRequest = $iApp->{_request};
+    my $svr      = $iApp->{_config}->get('Server');
 
     $iRequest->get_header('referer')    =~ /$svr/xms      and return 1;
     $iRequest->get_header('user-agent') =~ /Monazilla/xms and return 1;
@@ -882,7 +879,11 @@ sub get_text_info {
     ( $text =~ tr/\n//d, length $max );
 }
 
-sub count_anchors { $_[1] =~ s/&gt;&gt;(?:\d*-?\d*)//gxms }
+sub count_anchors {
+    my ( $iApp, $comment ) = @_;
+    my @comment = $comment =~ /&gt;&gt;(?:\d*-?\d*)/gxms;
+    return scalar @comment;
+}
 
 sub is_bbm {
     my ( $iClass, $serial, $now ) = @_;
@@ -892,6 +893,32 @@ sub is_bbm {
     join( '.', ( unpack( 'C*', $addr ) ) ) eq '127.0.0.2' ? 1 : 0;
 }
 
+sub get_plugin_config {
+    my ( $iApp, $plugin_id, $name, $merge_level ) = @_;
+    my $iKernel = $iApp->{__kernel};
+    my $bbs = $iApp->{__bbs}->get_name();
+    my $key = $iApp->{__key};
+    my $ret = [];
+
+    if ( $merge_level & 2 ) {
+        my $config = Img0ch::Plugin->retrive(
+            $plugin_id, $bbs, $key, $iKernel );
+        (( ref $config || '' ) eq 'HASH')
+            and push @$ret, $config->{$name};
+    }
+    if ( $merge_level & 1 ) {
+        my $config = Img0ch::Plugin->retrive(
+            $plugin_id, $bbs, undef, $iKernel );
+        (( ref $config || '' ) eq 'HASH')
+            and push @$ret, $config->{$name};
+    }
+    my $config = Img0ch::Plugin->retrive(
+        $plugin_id, undef, undef, $iKernel );
+    (( ref $config || '' ) eq 'HASH')
+        and push @$ret, $config->{$name};
+    return $ret;
+}
+
 sub is_make_new_thread { $_[0]->{__mkthread} ? 1 : 0 }
 
 sub is_sage { $_[0]->{__sage} ? 1 : 0 }
@@ -912,9 +939,11 @@ sub get_subject { $_[0]->{__param_subject} }
 
 sub set_subject { $_[0]->{__param_subject} = $_[1]; return; }
 
-sub get_ip { $_[0]->{__ip} }
+sub get_ip { $_[0]->{_ip} }
 
-sub get_ip_int { $_[0]->{__ip_int} }
+sub get_ip_int { $_[0]->{_ip_int} }
+
+sub get_remote_host { $_[0]->{_host} }
 
 sub set_error { $_[0]->{__error} = $_[1]; return; }
 
@@ -922,9 +951,11 @@ sub bbs { $_[0]->{__bbs} }
 
 sub cap { $_[0]->{__cap} }
 
+sub config { $_[0]->{_config} }
+
 sub kernel { $_[0]->{__kernel} }
 
-sub request { $_[0]->{__request} }
+sub request { $_[0]->{_request} }
 
 sub setting { $_[0]->{__setting} }
 
@@ -942,75 +973,26 @@ sub _switch {
 
     if ( $iApp->{__mkthread} ) {
         require Img0ch::Template;
-        my $iRequest = $iApp->{__request};
+        my $iRequest = $iApp->{_request};
         my $iSetting = $iApp->{__setting};
         my $comment  = $iRequest->param('MESSAGE');
         my $pwcheck  = $iSetting->is_checked('BBS_PASSWORD_CHECK');
-        if ( !$agent and $pwcheck ) {
-            if (    $comment
-                and !_is_cookie_set( $iApp, $iSetting )
-                and $iSetting->is_checked('BBS_NEWSUBJECT') )
-            {
-                my $iTemplate = Img0ch::Template->new(
-                    $iBBS,
-                    {   file    => 't_confirm',
-                        setting => $iSetting,
-                        version => $iRequest->credit(),
-                    }
-                );
-                $iTemplate->param(
-                    {   (   map { %{$_} } @{ $iApp->{__template_tag_confirm} }
-                        ),
-                        'Comment' => $comment,
-                        'Name'    => $iRequest->param('FROM'),
-                        'Mail'    => $iRequest->param('mail'),
-                        'Subject' => $iRequest->param('subject'),
-                    }
-                );
-                $iRequest->send_http_header();
-                $iTemplate->flush();
-                return 0;
-            }
-            else {
-                require Img0ch::Metadata;
-                my $iMeta     = Img0ch::Metadata->new($iBBS);
-                my $iTemplate = Img0ch::Template->new(
-                    $iBBS,
-                    {   file    => 't_form',
-                        setting => $iSetting,
-                        version => $iRequest->credit(),
-                    }
-                );
-                $iTemplate->param(
-                    {   ( map { %{$_} } @{ $iApp->{__template_tag_form} } ),
-                        'Banner' => $iMeta->main_banner(),
-                        'META'   => $iMeta->meta(),
-                        'HEAD'   => $iMeta->head(),
-                        'FOOT'   => $iMeta->foot(),
-                    }
-                );
-                $iRequest->send_http_header();
-                $iTemplate->flush();
-                return 0;
-            }
-        }
-        elsif ( $comment
-            and $pwcheck
-            and !_is_cookie_set( $iRequest, $iSetting ) )
-        {
+        if ( !$agent and $pwcheck and !$comment ) {
+            require Img0ch::Metadata;
+            my $iMeta     = Img0ch::Metadata->new($iBBS);
             my $iTemplate = Img0ch::Template->new(
                 $iBBS,
-                {   file    => 't_confirm',
+                {   file    => 't_form',
                     setting => $iSetting,
                     version => $iRequest->credit(),
                 }
             );
             $iTemplate->param(
-                {   ( map { %{$_} } @{ $iApp->{__template_tag_confirm} } ),
-                    'Comment' => $comment,
-                    'Name'    => $iRequest->param('FROM'),
-                    'Mail'    => $iRequest->param('mail'),
-                    'Subject' => $iRequest->param('subject'),
+                {   ( map { %{$_} } @{ $iApp->{__template_tag_form} } ),
+                    Banner => $iMeta->main_banner(),
+                    META   => $iMeta->meta(),
+                    HEAD   => $iMeta->head(),
+                    FOOT   => $iMeta->foot(),
                 }
             );
             $iRequest->send_http_header();
@@ -1021,16 +1003,6 @@ sub _switch {
     1;
 }
 
-sub _is_cookie_set {
-    if ( $_[1]->is_checked('BBS_NAMECOOKIE_CHECK') ) {
-        defined $_[0]->cookie('NAME') or return 0;
-    }
-    if ( $_[1]->is_checked('BBS_MAILCOOKIE_CHECK') ) {
-        defined $_[0]->cookie('MAIL') or return 0;
-    }
-    1;
-}
-
 sub _plugin {
     my ( $iApp, $iBBS, $iConfig, $at, $disable ) = @_;
 
@@ -1047,7 +1019,6 @@ sub _upload {
     my ( $iApp, $resno, $key, $iBBS, $iConfig, $iRequest, $iSetting ) = @_;
     my $filename = $iRequest->filename('file');
     my $ext;
-
     if ( !$iApp->{__cap}->can_post_without_limit()
         and $iRequest->fsize() > $iSetting->get_int('BBS_IMG_MAX_SIZE') )
     {
@@ -1067,11 +1038,20 @@ sub _upload {
         $iApp->{__error} = 'UPLOAD_INVALID_EXTENSION';
         return 0;
     }
+
+    my $remove_key = $iRequest->param('pass');
+    if ( !$remove_key
+        and $iSetting->is_checked('BBS_IMG_REQUIRE_REMOVE_KEY') ) {
+        $iApp->{__error} = 'UPLOAD_WITHOUT_REMOVE_KEY';
+        return 0;
+    }
+
     $iApp->_plugin( $iBBS, $iConfig, 'bbs.upload.pre',
         'DisableBBSPreUploadPlugin' )
         or return 0;
 
     $iUpload->set( $iRequest->tempfile(), $resno, $ext );
+    $iUpload->set_remove_password($remove_key);
     $iUpload->save();
 
     my $comment = $iApp->{__param_MESSAGE} || '';
@@ -1112,73 +1092,98 @@ sub _acceptable {
     0;
 }
 
-sub _redirect_success {
+sub redirect_success {
     my ($iApp)   = @_;
     my $iBBS     = $iApp->{__bbs};
-    my $iConfig  = $iApp->{__config};
-    my $iRequest = $iApp->{__request};
+    my $iConfig  = $iApp->{_config};
+    my $iRequest = $iApp->{_request};
 
-    require Img0ch::Metadata;
-    my $iTemplate = Img0ch::Template->new(
-        $iBBS,
-        {   file    => 'redirect',
-            setting => $iApp->{__setting},
-            version => $iRequest->credit(),
-        }
-    );
-    $iTemplate->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_redirect} } ),
-            'Banner'       => Img0ch::Metadata->new($iBBS)->main_banner(),
-            'RedirectWait' => ( $iConfig->get_int('RedirectWait') || 5 ),
-        }
-    );
-
-    my $charset = $iConfig->get('DefaultCharset');
-    $iRequest->send_http_header( 'text/html', $charset );
-    $iTemplate->flush();
+    if ($iRequest->param('js')) {
+        $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
+        print ${$iRequest->get_json({
+            ok => 1,
+            error => '',
+            errstr => '' })};
+    }
+    else {
+        require Img0ch::Metadata;
+        my $iTemplate = Img0ch::Template->new(
+            $iBBS,
+            {   file    => 'redirect',
+                setting => $iApp->{__setting},
+                version => $iRequest->credit(),
+            }
+        );
+        $iTemplate->param(
+            {   ( map { %{$_} } @{ $iApp->{__template_tag_redirect} } ),
+                'Banner'       => Img0ch::Metadata->new($iBBS)->main_banner(),
+                'RedirectWait' => ( $iConfig->get_int('RedirectWait') || 5 ),
+            }
+        );
+        my $charset = $iConfig->get('DefaultCharset');
+        $iRequest->send_http_header( 'text/html', $charset );
+        $iTemplate->flush();
+    }
     1;
 }
 
-sub _redirect_error {
-    my ($iApp) = @_;
-    my $iConfig = $iApp->{__config};
+sub redirect_error {
+    my ( $iApp, $template, $cs, $filter, $callback ) = @_;
+    my $iConfig = $iApp->{_config};
     my $iObject = $iApp->{__bbs} || $iApp->{__kernel};
-    my $iRequest = $iApp->{__request};
+    my $iRequest = $iApp->{_request};
 
     require Img0ch::Error;
     my $key = $iApp->{__key} || $iRequest->key();
-    my $iError = Img0ch::Error->new( $iObject, $key, $iApp->{__ip_int} );
-    my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
-    $iError->record();
+    my $iError = Img0ch::Error->new( $iObject, $key, $iApp->{_ip_int} );
+    my $error  = $iApp->{__error} || 'UNKNOWN_ERROR';
+    my $long   = $iError->get($error);
 
-    my $ip   = $iApp->{__host}       || $iApp->{__ip} || $iRequest->ip();
+    $iError->record();
+    while ( my ( $subs, $value ) = each %{$iApp->{__error_args}} ) {
+        $long =~ s/{!$subs!}/$value/gxms;
+    }
+
+    my $ip   = $iApp->{_host} || $iApp->{_ip} || $iRequest->ip();
     my $name = $iApp->{__param_FROM} || $iRequest->param('FROM');
     my $mail = $iApp->{__param_mail} || $iRequest->param('mail');
     my $message = $iApp->{__param_MESSAGE} || $iRequest->param('MESSAGE');
+    $callback and $callback->( $iApp, $long );
 
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        $iObject,
-        {   file    => 'error',
-            setting => $iApp->{__setting},
-            version => $iRequest->credit(),
-        }
-    );
-    $iTemplate->param(
-        {   ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
-            'Flag'          => 1,
-            'Host'          => $ip,
-            'LongErrorStr'  => $long,
-            'Name'          => $name,
-            'Mail'          => $mail,
-            'Message'       => $message,
-            'ShortErrorStr' => $long,
-        }
-    );
-
-    my $charset = $iConfig->get('DefaultCharset');
-    $iRequest->send_http_header( 'text/html', $charset );
-    $iTemplate->flush();
+    if ($iRequest->param('js')) {
+        require Unicode::Japanese;
+        $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
+        $long =~ tr/\r//d;
+        my $icode = Unicode::Japanese->getcode($long);
+        print ${$iRequest->get_json({
+            ok => 0,
+            error => $error,
+            errstr => Unicode::Japanese->new( $long, $icode )->get() })};
+    }
+    else {
+        require Img0ch::Template;
+        my $iTemplate = Img0ch::Template->new(
+            $iObject,
+            {   file    => ( $template || 'error' ),
+                setting => $iApp->{__setting},
+                version => $iRequest->credit(),
+            }
+        );
+        $iTemplate->param(
+            {   ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
+                'Flag'          => 1,
+                'Host'          => $ip,
+                'LongErrorStr'  => $long,
+                'Name'          => $name,
+                'Mail'          => $mail,
+                'Message'       => $message,
+                'ShortErrorStr' => $long,
+            }
+        );
+        my $charset = $cs || $iConfig->get('DefaultCharset');
+        $iRequest->send_http_header( 'text/html', $charset );
+        $iTemplate->flush($filter);
+    }
     0;
 }
 
@@ -1407,16 +1412,20 @@ datへの追記、subjectの更新など書き込みを実行します。
 
 =item Arguments
 
-$iBBS?
+$iBBS?, $execute_plugins?, $nodisk?
 
 =item Return Value
 
-1
+1 or $parameter_for_template($nodisk = true)
 
 =back
 
 subback.htmlを更新します。
 
+I<$execute_plugins>があればプラグインを実行します。
+
+I<$nodisk>があればsubback.htmlを作成せず、戻り値が1の代わりに
+Img0ch::Template::param()に渡すためのパラメータを返します。
 
 =head2 update_index
 
@@ -1424,16 +1433,23 @@ subback.htmlを更新します。
 
 =item Arguments
 
-$iBBS?
+$iBBS?, $execute_plugins?, $nodisk?
 
 =item Return Value
 
-1
+1 or @parameter_for_template($nodisk = true)
 
 =back
 
 index.html及び/i/index.htmlを更新します。
 
+I<$execute_plugins>があればプラグインを実行します。
+
+I<$nodisk>があればindex.html及び/i/index.htmlを作成せず、
+戻り値が1の代わりにImg0ch::Template::param()に渡すための
+パラメータを配列(0番目にindex.htmlの、1番目に/i/index.htmlの
+パラメータが入る)を返します。
+
 =head2 param
 
 =over 4
@@ -1835,6 +1851,22 @@ $ip_int
 
 現在のIPアドレス(*.*.*.*)の16進数のバイナリ文字列を返します。
 
+=head2 get_remote_host
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$host
+
+=back
+
+現在の投稿元(リモートホスト)の文字列を返します。
+
 =head2 set_error
 
 =over 4
@@ -1885,6 +1917,23 @@ $iCap (Img0ch::Cap)
 I<Img0ch::Cap>オブジェクトを返します。
 I<Img0ch::App::BBS::validate()>の途中から利用可能です。
 
+=head2 config
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$iConfig (Img0ch::Config)
+
+=back
+
+I<Img0ch::Config>オブジェクトを返します。
+I<Img0ch::App::BBS>オブジェクト生成後利用可能です。
+
 =head2 kernel
 
 =over 4
