@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: MailPost.pm 181 2007-02-05 14:02:27Z hikarin $
+# $Id: MailPost.pm 232 2007-02-14 13:57:07Z hikarin $
 #
 
 package Img0ch::App::MailPost;
@@ -96,6 +96,7 @@ sub redirect_success {
 sub get_mail {
     my ( $iApp, $mail_rec ) = @_;
     my $iConfig = $iApp->{_config};
+    my $iKernel = $iApp->kernel();
 
     my $user = $iConfig->get('POP3User');
     my $pass = $iConfig->get('POP3Pass');
@@ -108,15 +109,18 @@ sub get_mail {
         my @msgs    = sort { $a <=> $b } keys %$msgnums;
         my $msgnum  = shift @msgs;
         if ($msgnum) {
-            my $msg = $pop3->get($msgnum);
+            my $msg = $pop3->get($msgnum)
+                or $iKernel->throw_exception($pop3->message());
             @$mail_rec = @$msg;
-            $pop3->delete($msgnum);
+            $pop3->delete($msgnum)
+                or $iKernel->throw_exception($pop3->message());
+            $pop3->quit();
             return 1;
         }
         return 0;
     }
     else {
-        $iApp->kernel()->throw_exception($pop3->message());
+        $iKernel->throw_exception($pop3->message());
     }
 }
 
@@ -124,20 +128,30 @@ sub send_error_mail {
     my ( $iApp, $message ) = @_;
     my $iKernel = $iApp->kernel();
     my $iConfig = $iKernel->get_config();
+    my $from  = $iConfig->get('MailRawAddress');
+    my $to    = $iApp->{__from};
+
+    require Unicode::Japanese;
+    $message =~ s{<br\s?/?>}{\n}gxms;
+    my $icode = Unicode::Japanese->getcode($message);
+    my $message_jis = Unicode::Japanese->new( $message, $icode )->jis();
 
     require Email::Send;
     my $sender;
-    my $sendmail = $iConfig->get('SendmailPath');
-    if ( $sendmail ) {
+    if ( my $sendmail = $iConfig->get('SendmailPath') ) {
         $sender = Email::Send->new({ mailer => 'Sendmail' });
         $Email::Send::Sendmail::SENDMAIL = $sendmail;
     }
+    elsif ( my $qmail = $iConfig->get('QmailPath') ) {
+        $sender = Email::Send->new({ mailer => 'Qmail' });
+        $Email::Send::Qmail::QMAIL = $qmail;
+    }
     else {
         my $host = $iConfig->get('smtp.host');
         my $port = $iConfig->get_int('smtp.port');
         $port and $host = join ':', $host, $port;
         $sender = Email::Send->new({ mailer => 'SMTP' });
-        $sender->mail_args([
+        $sender->mailer_args([
             Host => $host,
             ssl => $iConfig->get('smtp.ssl'),
             tls => $iConfig->get('smtp.tls'),
@@ -145,15 +159,12 @@ sub send_error_mail {
     }
 
     require Img0ch::Template;
-    $message =~ s{<br\s?/?>}{\n}gxms;
-    my $from  = $iConfig->get('MailRawAddress');
-    my $to    = $iApp->{__from};
     my $iTemplate = Img0ch::Template->new(
         $iKernel, { file => 'mobile_error_mail' } );
     $iTemplate->param({
         From    => $from,
         To      => $to,
-        Message => $message,
+        Message => $message_jis,
     });
     my $result = $sender->send(${ $iTemplate->to_string() });
     $result or $iKernel->throw_exception($result);
@@ -165,6 +176,8 @@ sub process {
     my $iConfig = $iApp->{_config};
     my $iKernel = $iApp->kernel();
     my $iRequest = $iApp->request();
+
+    map { tr/\r\n//d } @$mail_rec;
     my $mime = Email::MIME->new(join "\r\n", @$mail_rec);
     $iApp->_get_host($iConfig, $mime) or return 0;
 
