@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 96 2007-01-16 13:47:54Z hikarin $
+# $Id: Read.pm 215 2007-02-10 13:05:38Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -101,7 +101,7 @@ sub init {
     require Img0ch::BBS;
     my $iBBS = Img0ch::BBS->new( $iApp->{_kernel},
         { bbs => $iApp->{_param_bbs}, } );
-    if ( !$iBBS->id() ) {
+    if ( !$iBBS->get_id() ) {
         $iApp->{__error} = 'INVALID_POST';
         return 0;
     }
@@ -250,7 +250,7 @@ sub _load_thread {
     my ( $reader, $read_res, $read_res_prev ) = ( undef, 100, 99 );
     if ($mobile) {
         my $cnum = $iRequest->param_int('RES')
-            || $iSetting->get('BBS_MB_CONTENTS_NUMBER')
+            || $iSetting->get_int('BBS_MB_CONTENTS_NUMBER')
             || 1;
         $read_res = $read_res_prev = $cnum;
     }
@@ -258,7 +258,7 @@ sub _load_thread {
         || join('/', $iConfig->get('Server'), 'test');
     my $renderer = $iConfig->get('Renderer') || 'read.cgi';
     $reader = join( '/',
-        $server, $renderer, $iBBS->bbs(), $iApp->{_param_key} );
+        $server, $renderer, $iBBS->get_name(), $iApp->{_param_key} );
 
     require Img0ch::Metadata;
     require Img0ch::Template;
@@ -340,10 +340,9 @@ sub _parse_from_request {
 
         $iApp->{_param_raw} = $raw;
         $raw =~ s/([acCi]+)\z//xms;
-        ( $path[1] || '' ) =~ /([\w\-]+)/xms;
+        ( $path[1] || 'test' ) =~ /([\w\-]+)/xms;
         $iApp->{_param_bbs} = $1;
-        '0000000000' =~ /\A(\d+)\z/xms;
-        ( $path[2] || '' ) =~ /(\d{9,10})/xms;
+        ( $path[2] || '0000000000' ) =~ /(\d{9,10})/xms;
         $iApp->{_param_key} = $1;
 
         my $main_parser = sub {
@@ -402,9 +401,9 @@ sub _parse_from_request {
                     = @{ $main_parser->($raw) };
                 $iApp->{_param_ls} = $read_recent;
                 $read_to ||= $max_read;
-                $iApp->{_param_single}
+                my $single = $iApp->{_param_single}
                     = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
-                $iApp->{_param_nofirst} = $read_nofirst;
+                $iApp->{_param_nofirst} = ( $single || $read_nofirst );
                 $read_from > $max_read and $read_from = $max_read;
                 $read_to > $max_read   and $read_to   = $max_read;
                 $swap->( \$read_from, \$read_to );
@@ -427,10 +426,10 @@ sub _parse_from_request {
             || $max_read;
         my $read_recent = $iApp->{_param_ls} = $iApp->get_param('last')
             || $iApp->get_param('ls');
-        $iApp->{_param_single}
+        my $single = $iApp->{_param_single}
             = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
-        $iApp->{_param_nofirst}
-            = $iApp->get_param('nofirst') eq 'true' ? 1 : 0;
+        $iApp->{_param_nofirst} = ( $single
+            || ( $iApp->get_param('nofirst') eq 'true' ? 1 : 0 ) );
         $read_from > $max_read and $read_from = $max_read;
         $read_to > $max_read   and $read_to   = $max_read;
         push @{$temp_range}, sort { $a <=> $b } ( $read_from .. $read_to );
@@ -513,6 +512,8 @@ sub _normalize {
 
 sub _redirect_error {
     my ($iApp)   = @_;
+    my $iBBS     = $iApp->{_bbs};
+    my $iConfig  = $iApp->{_config};
     my $iKernel  = $iApp->{_kernel};
     my $iRequest = $iApp->{_request};
 
@@ -522,36 +523,95 @@ sub _redirect_error {
     my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
     $iError->record();
 
+    my $bbs = $iBBS ? $iBBS->get_name() : '';
+    my $server = $iConfig->get('CGIServer')
+        || join('/', $iConfig->get('Server'), 'test');
+    my $renderer = $iConfig->get('Renderer') || 'read.cgi';
+    my $reader = join( '/', $server, $renderer, $bbs, $iApp->{_param_key} );
+    my $archive_path  = '';
+    my $archive_found = 0;
+    my $banner        = '';
+    my $dat_bytes     = 0;
+    my $is_error      = 0;
+    my $meta          = '';
+    my $pool_found    = 0;
+    my $res_count     = 0;
+    my $res_stack     = [];
+    my $subject       = '';
+    if ($iBBS) {
+        $archive_path = $iBBS->path('kako');
+        require Img0ch::Archive;
+        my $iArchive = Img0ch::Archive->new($iBBS);
+        ( $subject, $res_count ) = $iArchive->get($key);
+        if ($res_count) {
+            $archive_found = 1;
+        }
+        else {
+            require Img0ch::Pool::Subject;
+            my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
+            ( $subject, $res_count ) = @{ $iPSubject->get($key) };
+            if ($res_count) {
+                require Img0ch::Pool::Thread;
+                my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
+                $iPThread->load();
+                my @load_reses = ( 1 );
+                $res_count != 1 and push @load_reses, $res_count;
+                for my $i (@load_reses) {
+                    my $res  = $iPThread->get($i);
+                    my $id   = $res->[3];
+                    my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
+                    my $text = $res->[4];
+                    push @{$res_stack},
+                        {
+                        'num'     => $i,
+                        'resno'   => $i,
+                        'name'    => $res->[0],
+                        'mail'    => $res->[1],
+                        'date'    => $date,
+                        'text'    => $text,
+                        'isFirst' => ( $i == 1 ? 1 : 0 ),
+                        };
+                }
+                $dat_bytes  = $iPThread->size();
+                $pool_found = 1;
+            }
+        }
+        require Img0ch::Metadata;
+        my $iMeta = Img0ch::Metadata->new($iBBS);
+        $banner = $iMeta->main_banner();
+        $meta   = $iMeta->meta();
+    }
+    else {
+        $is_error = 1;
+    }
+
     require Img0ch::Template;
     my $iTemplate = Img0ch::Template->new(
-        $iKernel,
-        {   file    => 'error',
+        ( $iBBS || $iKernel ),
+        {   file    => 'not_found',
             setting => $iApp->{_setting},
             version => $iRequest->credit(),
         }
     );
     $iTemplate->param(
         {   ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
-
-            #        'Archive' => join('/', $server, $bbs, 'kako'),
-            'Banner' => '',
-
-            #        'DatByteSize' => $bytes,
-            #        'DatKByteSize' => int($bytes / 1024),
-            #        'IsArchived' => $found,
-            'IsError' => 1,
-
-            #        'IsPooled' => $pool,
-            #        'Token1' => substr($key, 0, 4),
-            #        'Token2' => substr($key, 0, 5),
+            'Archive' => $archive_path,
+            'Banner' => $banner,
+            'DatByteSize' => $dat_bytes,
+            'DatKByteSize' => int($dat_bytes / 1024),
+            'IsArchived' => $archive_found,
+            'IsError' => $is_error,
+            'IsPooled' => $pool_found,
+            'Token1' => substr( $key, 0, 4 ),
+            'Token2' => substr( $key, 0, 5 ),
             'LongErrorStr' => $long,
-            'META'         => '',
-
-            #        'ReadCGIURI' => join('/', $cgipath, $bbs, $key),
-            #        'ResCount' => $i,
+            'META'         => $meta,
+            'ReadCGIURI' => $reader,
+            'ResCount' => $res_count,
             'ShortErrorStr' => $long,
-
-            #        'ZThread' => $stack,
+            'Subject' => $subject,
+            'Thread' => $res_stack,
+            'ZThread' => $res_stack,
         }
     );
     $iApp->{_request}->send_http_header('text/html');
