@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Request.pm 105 2007-01-20 12:48:32Z hikarin $
+# $Id: Request.pm 132 2007-01-25 14:01:06Z hikarin $
 #
 
 package Img0ch::CGI::Request;
@@ -29,7 +29,7 @@ sub new {
     my ( $iClass, $param ) = @_;
     my $q = CGI::Minimal->new();
     $param and $q->param($param);
-    bless { __cgi => $q }, $iClass;
+    bless { __cgi => $q, __header => {} }, $iClass;
 }
 
 sub signature {
@@ -111,6 +111,7 @@ sub get_header {
 
 sub set_header {
     my ( $iRequest, $key, $value ) = @_;
+    $iRequest->{__header}->{$key} = $value;
     $key =~ tr/\-/_/;
     $key = 'HTTP_' . uc $key;
     $ENV{$key} = $value;
@@ -197,10 +198,10 @@ sub send_http_header {
     $type ||= 'text/html';
     $charset = defined $charset ? $charset : 'Shift_JIS';
 
-    if ( ( ref $extend || '' ) eq 'HASH' ) {
-        while ( my ( $key, $value ) = each %$extend ) {
-            print ucfirst($key), ': ', $value, "\n";
-        }
+    my $header = $iRequest->{__header};
+    ( ref $extend || '' ) eq 'HASH' and %$header = ( %$header, %$extend );
+    while ( my ( $key, $value ) = each %$header ) {
+        print ucfirst($key), ': ', $value, "\n";
     }
     map { print 'Set-Cookie: ', $_, "\n" } @{ $iRequest->{__cookie} || [] };
 
