@@ -14,15 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Maple.pm 152 2007-01-28 12:48:56Z hikarin $
+# $Id: Maple.pm 210 2007-02-10 12:53:52Z hikarin $
 #
 
 package Img0ch::Maple;
 
 use strict;
 
-$Img0ch::Maple::RCS_ID   = '$Id: Maple.pm 152 2007-01-28 12:48:56Z hikarin $';
-$Img0ch::Maple::VERSION  = '2.1.4';
+$Img0ch::Maple::RCS_ID   = '$Id: Maple.pm 210 2007-02-10 12:53:52Z hikarin $';
+$Img0ch::Maple::VERSION  = '2.1.5';
 $Img0ch::Maple::revision = do {
     my @rv = $Img0ch::Maple::RCS_ID =~ /(\d+)/xms;
     $rv[0];
@@ -135,6 +135,8 @@ sub get_repos_type {
         'CDB'        => 'CDB',
         'CDB_File'   => 'CDB',
         'Compressed' => 'Archive',
+        'DBMDeep'    => 'DD',
+        'DD'         => 'DD',
         'Depot'      => 'Qdepot',
         'FlatFile'   => 'Simple',
         'QDBM'       => 'Qdepot',
