@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: RSS.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: RSS.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Img0ch::Plugin::BBS::RSS;
@@ -38,7 +38,7 @@ sub generate_ver_10 {
     my $iKernel  = $iApp->kernel();
     my $iConfig  = $iKernel->get_config();
     my $iSetting = $iApp->setting();
-    my $bbs      = $iBBS->bbs();
+    my $bbs      = $iBBS->get_name();
     my $encoding = $iKernel->get_encoding(1);
     my $unijp    = Unicode::Japanese->new();
     my $url      = $iBBS->url();
