@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: DNSBL.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: DNSBL.pm 68 2007-01-05 13:02:12Z hikarin $
 #
 
 package Img0ch::Plugin::Filter::DNSBL;
@@ -33,14 +33,35 @@ sub check_by_dsbl {
     _check_proxy( '%d.%d.%d.%d.list.dbsl.org', @_ );
 }
 
+sub by_rbl {
+    _check_proxy( '%d.%d.%d.%d.all.rbl.jp', @_ );
+}
+
+sub by_spamcop {
+    _check_proxy( '%d.%d.%d.%d.bl.spamcop.net', @_ );
+}
+
+sub by_spamhaus {
+    _check_proxy( '%d.%d.%d.%d.sbl-xbl.spamhaus.org', @_ );
+}
+
+sub by_blitzed {
+    _check_proxy( '%d.%d.%d.%d.opm.blitzed.org', @_ );
+}
+
+sub by_empty {
+    _check_proxy( '%d.%d.%d.%d.bsb.empty.us', @_ );
+}
+
+sub by_spamlookup {
+    _check_proxy( '%d.%d.%d.%d.bsb.spamlookup.net', @_ );
+}
+
 sub _check_proxy {
     my ( $base, $iApp ) = @_;
-
     my $addr = sprintf $base, ( reverse split '\.', $iApp->get_ip() );
-    $addr = gethostbyname($addr) || $iApp->get_ip_int();
-    $addr = join '.', unpack( 'C*', $addr );
 
-    if ( $addr eq '127.0.0.2' ) {
+    if (gethostbyname($addr)) {
         if ( $iApp->setting()->is_checked('BBS_OVERSEA_PROXY') ) {
             $iApp->cap()->can_pass_proxy_access() and return 1;
             $iApp->set_error('DENY_FROM_PROXY_ACCESS');
