@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Image.pm 131 2007-01-25 14:00:47Z hikarin $
+# $Id: Image.pm 197 2007-02-08 13:34:17Z hikarin $
 #
 
 package Img0ch::Plugin::Rewrite::Image;
@@ -23,19 +23,24 @@ use strict;
 use Img0ch::Setting qw();
 use Img0ch::Upload qw();
 
+my $removeText = pack 'C*', 0x8d, 0xed, 0x8f, 0x9c;
 sub new {
     my ( $iClass, $iBBS, $key ) = @_;
     my $iConfig  = $iBBS->get_kernel()->get_config();
     my $iSetting = Img0ch::Setting->new($iBBS);
     my $iUpload  = Img0ch::Upload->new( $iBBS, $key );
     my $freezed  = ( stat( $iBBS->path('img') ) )[2] & 07777 == 0700;
+    my $bbs      = $iBBS->get_name();
     my $lightbox = $iConfig->get('UploadImageLinkRelative') || 'lightbox[%s]';
     my $url      = $iBBS->url('img');
+    my $ufm      = ( $iConfig->get('CGIServer')
+        || join( '/', $iConfig->get('Server'), 'test' ) )
+        . '/img0ch-ufm.cgi/' . $bbs . '/';
 
     bless {
-        __bbs              => $iBBS->bbs(),
-        __cache_key        => $key,
+        __bbs              => $bbs,
         __base_file_url    => $url,
+        __cache_key        => $key,
         __is_freezed       => $freezed,
         __i0_upload        => $iUpload,
         __link_relative    => $lightbox,
@@ -43,6 +48,7 @@ sub new {
         __thumbnail_max    => $iSetting->get('BBS_IMG_THUMBNAIL_MAX'),
         __thumbnail_width  => $iSetting->get('BBS_IMG_THUMBNAIL_X'),
         __thumbnail_height => $iSetting->get('BBS_IMG_THUMBNAIL_Y'),
+        __ufm              => $ufm,
         __use_fileseek     => $iConfig->get('UseFileSeek'),
         __use_picto        => $iConfig->get('UsePicto'),
     }, $iClass;
@@ -58,7 +64,7 @@ sub from_bbs {
     }
 
     my ( $extension, $width, $height, $hash ) = @{ $iUpload->get($resno) };
-    $extension or return;
+    $hash or return;
 
     my $max             = $iObject->{__thumbnail_max};
     my $base_file_url   = join '/', $iObject->{__base_file_url}, $key;
@@ -82,6 +88,11 @@ sub from_bbs {
         my $max_height = $iObject->{__thumbnail_height};
         $relative =~ s/%s/${bbs_dir}_${key}/xms;
 
+        my $removeLink = '<a href="' . $iObject->{__ufm} . $key . '/';
+        $removeLink .= $resno . '" onclick="app.removeFile( this, ' . $key;
+        $removeLink .= ', ' . $resno . ' ); return false">[';
+        $removeLink .= $removeText . ']</a>';
+
         if ((       $extension ne 'jpg'
                 and $extension ne 'gif'
                 and $extension ne 'png'
@@ -93,7 +104,8 @@ sub from_bbs {
                 '<a href="', $file_url, '" class="i0_image" id="f', $key,
                 '_', $resno, '" rel="', $relative, '" title="',
                 $file_name, '"><b>[', $extension,  ']</b></a>' );
-            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}{$format($1)<br$2>}xms;
+            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
+                {$format$removeLink($1)<br$2>}xms;
         }
         elsif ( $iUpload->get_thumbnail_size(
             $resno, \$scaled_width, \$scaled_height ) ) {
@@ -116,7 +128,8 @@ sub from_bbs {
                 '_',                $key,
                 '_',                $resno,
                 '" class="image" /></a>' );
-            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}{${format}($1)<br$2>}xms;
+            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
+                {$format($1)$removeLink<br$2>}xms;
             $$text .= '<br class="clear" />';
         }
         elsif ( $width and $height ) {
@@ -138,7 +151,8 @@ sub from_bbs {
                 '_',                $key,
                 '_',                $resno,
                 '" class="image" /></a>' );
-            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}{$format($1)<br$2>}xms;
+            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
+                {$format($1)$removeLink<br$2>}xms;
             $$text .= '<br class="clear" />';
         }
         else {
@@ -146,7 +160,8 @@ sub from_bbs {
                 '<a href="', $file_url, '" class="i0_file" id="f',
                 $bbs_dir, '_', $key, '_', $resno, '">', '<b>[',
                 $extension,  ']</b></a>' );
-            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}{$format($1)<br$2>}xms;
+            $$text =~ s{\A.+?\((.+?)\)<br(\s/)?>}
+                {$format$removeLink($1)<br$2>}xms;
         }
     }
     return;
