@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Setting.pm 164 2007-02-02 14:52:06Z hikarin $
+# $Id: Setting.pm 198 2007-02-08 13:39:47Z hikarin $
 #
 
 package Img0ch::Setting;
@@ -65,6 +65,12 @@ sub get {
     $iSetting->{__cache}->{$key} = $value;
 }
 
+sub set {
+    my ( $iSetting, $key, $value ) = @_;
+    $iSetting->{__cache}->{$key} = $value;
+    return;
+}
+
 sub get_hash {
     my ($iSetting) = @_;
     my $iReposCommon = $iSetting->{_common};
@@ -185,6 +191,23 @@ $string_of_value
 未定義の場合ナルストリングが返されます。
 二回目に呼び出されたときは一回目に呼び出したときにキャッシュした値を返します。
 
+=head2 set
+
+=over 4
+
+=item Arguments
+
+$key, $value
+
+=item Return Value
+
+none
+
+=back
+
+指定されたSETTING.TXTの値をオブジェクト内部のキャッシュに設定します。
+このため、指定された値はオブジェクトが生存する限り有効です。
+
 =head2 get_hash
 
 =over 4
