@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Upload.pm 99 2007-01-16 13:52:38Z hikarin $
+# $Id: Upload.pm 198 2007-02-08 13:39:47Z hikarin $
 #
 
 package Img0ch::Upload;
@@ -24,7 +24,7 @@ use Digest::MD5 qw();
 
 sub new {
     my ( $iClass, $iBBS, $key ) = @_;
-    my $bbs     = $iBBS->bbs();
+    my $bbs     = $iBBS->get_name();
     my $iKernel = $iBBS->get_kernel();
 
     my $repos_tag = $iBBS->get_repos_path('tag');
@@ -89,9 +89,10 @@ sub save {
         mkdir $dir, 0755 or $iKernel->throw_io_exception($dir);
     }
 
+    my ( $bbs, $key ) = ( $iUpload->{_dir}, $iUpload->{_key} );
     my ( $src, $resno, $ext ) = ( $line->[0], $line->[1], $line->[2] );
     my $path = $iUpload->path( $resno, $ext );
-    -r $path and return 0;
+    my $file_not_uploaded = -r $path ? 0 : 1;
 
     require File::Copy;
     local $!;
@@ -100,14 +101,14 @@ sub save {
         $iKernel->throw_io_exception($file);
     }
 
-    my ( $bbs, $key ) = ( $iUpload->{_dir}, $iUpload->{_key} );
     my ( $width, $height ) = $iUpload->get_dimensions($src);
     my $prefix       = "I:U:I.${bbs}.${key}.${resno}";
-    $iReposUpload->set( "${prefix}.extension",   $ext );
-    $iReposUpload->set( "${prefix}.width",       $width );
-    $iReposUpload->set( "${prefix}.height",      $height );
-    $iReposUpload->set( "${prefix}.hash",        $iUpload->get_digest($src) );
-    $iReposUpload->set( "I:U:I.${bbs}.${key}._", ++$iUpload->{_count} );
+    $iReposUpload->set( "${prefix}.extension", $ext );
+    $iReposUpload->set( "${prefix}.width",     $width );
+    $iReposUpload->set( "${prefix}.height",    $height );
+    $iReposUpload->set( "${prefix}.hash",      $iUpload->get_digest($src) );
+    $file_not_uploaded and $iReposUpload->set(
+        "I:U:I.${bbs}.${key}._", ++$iUpload->{_count} );
     if ( my $dlkey = $iUpload->{__dlpass} ) {
         chmod 0600, $path;
         $iReposUpload->set( "${prefix}.download.pass",
@@ -435,20 +436,29 @@ sub remove {
     }
     my $prefix        = "I:U:I.${bbs}.${key}.${resno}";
     my $extension     = $iReposUpload->get("${prefix}.extension");
-    my $uploaded_file_path = $iUpload->path( $resno, $extension );
 
-    if ( -f $uploaded_file_path and -w $uploaded_file_path ) {
+    my $uploaded_file_path = $iUpload->path( $resno, $extension );
+    if ( ( -f $uploaded_file_path or -l $uploaded_file_path )
+        and -w $uploaded_file_path ) {
         my $iKernel = $iUpload->{_kernel};
         unlink $uploaded_file_path
             or $iKernel->throw_io_exception($uploaded_file_path);
     }
+    my $thumbnail = $iUpload->path( "t${resno}", $extension );
+    if ( ( -f $thumbnail or -l $thumbnail ) and -w $thumbnail ) {
+        my $iKernel = $iUpload->{_kernel};
+        unlink $thumbnail or $iKernel->throw_io_exception($thumbnail);
+    }
 
+    $iReposUpload->remove("${prefix}.remove");
     $iReposUpload->remove("${prefix}.extension");
     $iReposUpload->remove("${prefix}.width");
     $iReposUpload->remove("${prefix}.height");
-    $iReposUpload->remove("${prefix}.hash");
+    $iReposUpload->remove("${prefix}.width.thumbnail");
+    $iReposUpload->remove("${prefix}.height.thumbnail");
     $iReposUpload->remove("${prefix}.download.pass");
-    $iReposUpload->remove("${prefix}.remove.pass");
+    $iReposUpload->set( "${prefix}.hash", $iUpload->removed_mark() );
+    $iReposUpload->set( "I:U:I.${bbs}.${key}._", --$iUpload->{_count} );
     return 1;
 }
 
