@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Metadata.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: Metadata.pm 123 2007-01-23 13:52:09Z hikarin $
 #
 
 package Zeromin::Metadata;
@@ -30,13 +30,13 @@ sub new {
     if ( $class eq 'Img0ch::BBS' or $class eq 'Zeromin::BBS' ) {
         $zMeta             = $zClass->SUPER::new($iObject);
         $zMeta->{__kernel} = $iObject->get_kernel();
-        $iRepos            = $iObject->get_common_repos();
     }
     elsif ( $class eq 'Img0ch::Maple' ) {
         $zMeta = bless {
             _bbs     => 'test',
+            _common => $iObject->get_repos(
+                $iObject->get_repos_path('common') ),
             __kernel => $iObject,
-            _rs => $iObject->get_repos( $iObject->get_repos_path('common') ),
         }, $zClass;
     }
     else {
@@ -63,7 +63,7 @@ sub thread_end { shift->_switch( 'thread', '1000.txt', @_ ) }
 
 sub remove {
     my ( $zMeta ) = @_;
-    my ( $iRepos, $dir ) = ( $zMeta->{_rs}, $zMeta->{_bbs} );
+    my ( $iRepos, $dir ) = ( $zMeta->{_system}, $zMeta->{_bbs} );
     $iRepos->remove("I:M.${dir}.head");
     $iRepos->remove("I:M.${dir}.meta");
     $iRepos->remove("I:M.${dir}.foot");
@@ -81,16 +81,15 @@ sub _switch {
 
 sub _save {
     my ( $zMeta, $type, $file, $content ) = @_;
-    my ( $iRepos, $dir )
-        = ( $zMeta->{_rs}, ( $file ? $zMeta->{_bbs} : 'test' ) );
+    my ( $iReposCommon, $iReposSystem, $dir )
+        = ( $zMeta->{_common}, $zMeta->{_system},
+        ( $file ? $zMeta->{_bbs} : 'test' ) );
     my $iKernel = $zMeta->{__kernel};
 
     require Zeromin::Plugin;
     my $zPlugin = Zeromin::Plugin->new($iKernel);
     $zPlugin->do( "zeromin.update.${type}",
         $zMeta, [ $zMeta->{_bbs}, $content ] );
-    $iRepos->set_binary( "I:M.${dir}.${type}", $$content );
-    $iRepos->save();
 
     if ($file) {
         my $iKernel = $zMeta->{__kernel};
@@ -102,6 +101,14 @@ sub _save {
         print {*FH} ${$content}
             or $iKernel->throw_io_exception($path);
         close *FH or $iKernel->throw_io_exception($path);
+        $iReposSystem->set_binary( "I:M.${dir}.${type}", $$content );
+        $iReposSystem->save();
+        $iReposCommon->remove("I:M.${dir}.${type}");
+        $iReposCommon->save();
+    }
+    else {
+        $iReposCommon->set_binary( "I:M.${type}", $$content );
+        $iReposCommon->save();
     }
 
     return 1;
