@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Plugin.pm 100 2007-01-16 13:52:52Z hikarin $
+# $Id: Plugin.pm 164 2007-02-02 14:52:06Z hikarin $
 #
 
 package Zeromin::Plugin;
@@ -418,11 +418,15 @@ sub install {
         my $num   = $type2num->{$type};
         my $count = 0;
         $num or next;
-        exists $loaded->{$method} and next;
-
-        # pid, type, default is disabled, installing
-        $merge->{$method} = [ 0, $num, 0, 1 ];
-        $zPlugin->{__installed}++;
+        if ( exists $loaded->{$method} ) {
+            $merge->{$method} = $loaded->{$method};
+            $merge->{$method}->[1] = $num;
+        }
+        else {
+            # pid, type, default is disabled, installing
+            $merge->{$method} = [ 0, $num, 0, 1 ];
+            $zPlugin->{__installed}++;
+        }
     }
     my $temp = $zPlugin->{__load}->{$class} || {};
     $zPlugin->{__load}->{$class} = { %{$temp}, %{$merge} };
@@ -631,7 +635,7 @@ sub remove_from_bbs {
 
     require Img0ch::BBS;
     my $iBBS = Img0ch::BBS->new( $zPlugin->{__kernel}, { id => $bbs_id } );
-    my $bbs_dir = $iBBS->bbs() or return 0;
+    my $bbs_dir = $iBBS->get_name() or return 0;
 
     my $iReposEntries = $zPlugin->{_repos};
     $iReposEntries->remove("I:P.enabled.${bbs_dir}");
